Summary:	Lightweight, non-caching, optionally anonymizing HTTP proxy
Name:		tinyproxy
Version:	1.10.0
Release:	%mkrel 2
Group:		System/Servers
# License bundled is gpl v3, but source code say gpl v2 or later
License:	GPLv2+
URL:		https://tinyproxy.github.io/
Source0:	https://github.com/%{name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:	tinyproxy.init
Patch0:		tinyproxy-1.8.3-group.patch
BuildRequires:	asciidoc
BuildRequires:	xsltproc
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook-dtd45-xml
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description
An anonymizing http proxy which is very light on system resources, ideal for
smaller networks and similar situations where other proxies (such as Squid) may
be overkill and/or a security risk. Tinyproxy can also be configured to
anonymize http requests (allowing for exceptions on a per-header basis).

%prep

%setup -q
%patch0 -p1 -b .group

cp %{SOURCE1} tinyproxy.init

%build
# fix build on aarch64
autoreconf -vfi

%serverbuild
%configure \
    --enable-xtinyproxy \
    --enable-filter \
    --enable-upstream \
    --enable-transparent \
    --enable-reverse \
    --sysconfdir=%{_sysconfdir}/tinyproxy \
    --with-stathost=localhost \
    --program-prefix=""

%make_build

%install
%__install -d %{buildroot}%{_sysconfdir}/tinyproxy
%__install -d %{buildroot}%{_sysconfdir}/logrotate.d
%__install -d %{buildroot}%{_sysconfdir}/sysconfig
%__install -d %{buildroot}%{_initrddir}

%__install -d %{buildroot}%{_logdir}/tinyproxy

%makeinstall bindir=%{buildroot}%{_sbindir}

# README{.md} is actually an INSTALL file, so we remove it
rm -f %{buildroot}%{_datadir}/doc/%{name}/README*

/bin/touch %{buildroot}%{_sysconfdir}/tinyproxy/filter

%__install -m0755 tinyproxy.init %{buildroot}%{_initrddir}/tinyproxy

/bin/echo "FLAGS=\" -c /etc/tinyproxy/tinyproxy.conf\"" > %{buildroot}%{_sysconfdir}/sysconfig/tinyproxy

cat > %{buildroot}%{_sysconfdir}/logrotate.d/tinyproxy <<EOF
/var/log/tinyproxy.log {
    rotate 7
    daily
    compress
    missingok
    postrotate
    if [ -f /run/tinyproxy.pid ]; then
       /etc/init.d/tinyproxy restart > /dev/null
    fi
    endscript
}
EOF

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/tinyproxy 0755 root root
EOF

%post
%_tmpfilescreate %{name}
%_post_service tinyproxy

%preun
%_preun_service tinyproxy


%files
%doc docs/*.txt
%doc AUTHORS NEWS TODO 
%attr(0755,root,root) %{_sbindir}/tinyproxy
%attr(0755,root,root) %{_initrddir}/tinyproxy
%config(noreplace) %{_sysconfdir}/sysconfig/tinyproxy
%config(noreplace) %{_sysconfdir}/logrotate.d/tinyproxy
%dir %{_sysconfdir}/tinyproxy
%config(noreplace) %{_sysconfdir}/tinyproxy/tinyproxy.conf
%config(noreplace) %{_sysconfdir}/tinyproxy/filter
%{_tmpfilesdir}/%{name}.conf
%{_logdir}/tinyproxy/
%{_mandir}/man8/tinyproxy.8*
%{_mandir}/man5/*
%{_datadir}/tinyproxy
%license COPYING


%changelog
* Fri Feb 14 2020 umeabot <umeabot> 1.10.0-2.mga8
+ Revision: 1520228
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 07 2018 solbu <solbu> 1.10.0-1.mga7
+ Revision: 1328840
- Move COPYING to the proper license directory, and don't package the INSTALL file
- New version: 1.10.0
- New upstream URL
- Drop CVE patches 1 and 2: Merged upstream
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 wally <wally> 1.8.3-10.mga7
+ Revision: 1242830
- fix build on aarch64

* Mon Feb 08 2016 umeabot <umeabot> 1.8.3-9.mga6
+ Revision: 946818
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.8.3-8.mga5
+ Revision: 748800
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.3-7.mga5
+ Revision: 689897
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.8.3-6.mga4
+ Revision: 522680
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 1.8.3-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 1.8.3-4.mga3
+ Revision: 384587
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ luigiwalser <luigiwalser>
- add tmpfiles config for /run/tinyproxy

* Fri Nov 02 2012 luigiwalser <luigiwalser> 1.8.3-3.mga3
+ Revision: 312602
- fix pid file in init script
- fix default group ID of processes in tinyproxy.conf

* Wed Oct 24 2012 luigiwalser <luigiwalser> 1.8.3-2.mga3
+ Revision: 309731
- add patches from debian to fix CVE-2012-3505

* Thu Aug 18 2011 misc <misc> 1.8.3-1.mga2
+ Revision: 134307
- fix initscript keyword ( rpmlint rejection)
- upgrade to newer version 1.8.3
- remove ndded part of the spec file
- place each BuildRequires on a line ( easier to spot change )
- remove provides on webproxy ( not required anywhere, and provides
  are not mean to be used for categorization )
- remove Epoch 0 ( breaking upgrade path, but we do not plan to support
  upgrade from 2010.2 or 2011 to mageia 2 )
- imported package tinyproxy


* Wed Aug 25 2010 Lev Givon <lev@mandriva.org> 0:1.8.2-1mdv2011.0
+ Revision: 573016
- Update to 1.8.2.
  Add docbook-dtd45-xml as build req.
  Update init file.

* Thu Jan 28 2010 Michael Scherer <misc@mandriva.org> 0:1.8.0-1mdv2010.1
+ Revision: 497568
- new version 1.8.0
- remove patch, as it is not needed, it is better to move file in %%install
- remove deprecated configure options, and enable new one
- remove uneeded BuildRequires

  + Lev Givon <lev@mandriva.org>
    - Update to 1.6.5.

* Sun May 10 2009 Lev Givon <lev@mandriva.org> 0:1.6.4-6mdv2010.0
+ Revision: 374022
- Bump release to force rebuild.
- Add logrotate script.

  + Michael Scherer <misc@mandriva.org>
    - update License
    - use new url
    - add socks support
    - update patch1 to make it compile

* Wed Nov 19 2008 Caio Begotti <caio1982@mandriva.org> 0:1.6.4-2mdv2009.1
+ Revision: 304532
- transparent proxy support is necessary to make kpcontrol works correctly, and distros like ubuntu and debian have this on by default anyway (so it's probably safe for us too)

* Sat Sep 06 2008 Oden Eriksson <oeriksson@mandriva.com> 0:1.6.4-1mdv2009.0
+ Revision: 282035
- 1.6.4
- spec file cleanup

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 0:1.6.3-6mdv2009.0
+ Revision: 254610
- rebuild

* Mon Feb 18 2008 Oden Eriksson <oeriksson@mandriva.com> 0:1.6.3-4mdv2008.1
+ Revision: 171232
- add a virtal provides of webproxy

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon May 07 2007 David Walluck <walluck@mandriva.org> 0:1.6.3-3mdv2008.0
+ Revision: 24020
- use %%mkrel
- add LSB support to initscript
- remove PreReq and use Requires() instead
- Import tinyproxy



* Mon Nov  1 2004 Michael Scherer <misc@mandrake.org> 1.6.3-2mdk
- Fix build

* Wed Aug 11 2004 Lenny Cartier <lenny@mandrakesoft.com> 1.6.3-1mdk
- 1.6.3

* Wed Dec 03 2003 Florin <florin@mandrakesoft.com> 1.6.2-1mdk
- 1.6.2

* Mon Aug 04 2003 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.6.0a-1mdk
- 1.6.0a
- rm -rf $RPM_BUILD_ROOT in %%install, not %%prep
- add unpackaged files

* Wed Nov 20 2002 Florin <florin@mandrakesoft.com> 1.5.2-0.rc1.1mdk
- 1.5.2rc1
- add the --program-prefix="" configure option
- bzip2 the patch
- add the filter file/directory

* Fri Oct 04 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.5.1-1mdk
- 1.5.1

* Wed Dec 12 2001 Philippe Libat <philippe@mandrakesoft.com> 1.4.3-1mdk
- First spec
